@@ -8,7 +8,16 @@ from .mini_logger import MiniLogger as logger
 class OurObject(ABC):
 
     entity_name = None
-    fields = {}
+
+    # Needed by print_our_object_with_id()
+    name = None
+    number = None
+
+    fields = {
+        # Needed by print_our_object_with_id()
+        "name",
+        "number"
+    }
 
     def __init__(self, entity_name, **kwargs):
         INIT_METHOD_NAME = '__init__'
@@ -30,6 +39,11 @@ class OurObject(ABC):
             else:
                 setattr(self, field, None)
 
+    def get_id_column_name(self) -> str:
+        """Returns the name of the column that is used as the id of the object"""
+        id_column_name = self.entity_name + "_id"
+        return id_column_name
+
     # Commented so we can use it in database foreach()
     # @abstractmethod
     def get_name(self):
